#!/bin/sh

library(grid)
library(rgdal)
library(pryr)
library(reshape2)
library(riverplot)
library(lattice)
library(latticeExtra)

MyHomeDirectory <- c("SET_PATH_TO_WHERE_YOU_HAVE_STORED_THE_DATA_ANALYSIS_SCRIPT!!!")		# put the path to your own directory down here
DataAnalysis <- paste(MyHomeDirectory,"Data_analysis.R",sep="")
# source(DataAnalysis)

# labels

varlong <- c("Savanna tree cover","Forest tree cover","Aboveground tree biomass [t/ha]","C3:C4 grass ratio","Mean tree height [m]","Maximum tree height [m]","Number of tree individuals [ha-1]","Aboveground grass biomass [t/ha]","Total tree cover")
varlab2 <- c("Savanna TC","Forest TC","Abg. tree biomass","C3:C4 grass ratio","Mean tree height","Max. tree height","No. of tree ind.","Abg. grass biomass","Total tree cover")

ewf85 <- 1
ewf45 <- 3
enf85 <- 5
enf45 <- 7
twf85 <- 2
twf45 <- 4
tnf85 <- 6
tnf45 <- 8

# color palette tables 

dist_cpt <- c("#0A0079","#1405AF","#0019D4","#1A66F0","#19AFFF","#44CAFF","#6AEBE1","#CDFFA2","#F0EC79","#F7D768","#FFBD57","#FFA045","#F4754B","#EE504E","#FF5A5A","#FF7C7C","#FF9E9E","#F5B3AE","#FFC4C4","#FFEBEB")
vars_cpt <- c("#E6194B","#F58231","#FFE119","#BFEF45","#3CB44B","#42D4F4","#4363D8","#911EB4","#F032E6")
lag2_cpt <- c("#FFFFFF","#EFEBE9","#FFF59D","#FFEE58","#DCE775","#AED581","#66BB6A","#26C6DA","#2196F3","#5C6BC0","#F06292","#E91E63","#AD1457")
biome_cpt1 <- c("#F2F1F0","#FFFF99","#FFBF80","#B3FF8C","#FF99BF","#A6EDFF","#CCBFFF")
perc_cpt <- c("#EFEBE9","#FFCCBC","#FFCC80","#FFF176","#D4E157","#9CCC65","#66BB6A","#26C6DA","#7986CB","#F06292")
NoBT_cpt <- c("#2196F3","#80DEEA","#9CCC65","#D4E157","#FFEB3B","#FFC107")
ratio_cpt <- c("#FAFAFA","#E3F2FD","#BBDEFB","#4DD0E1","#4CAF50","#8BC34A","#C0CA33","#FDD835","#FFA000","#E64A19","#6D4C41")

#---------------------------------------------------------------------------------------
# coastlines and country outlines to overlay over maps - using Natural Earth 

HomeOfShapefile <- c("SET_PATH_TO_WHERE_YOU_HAVE_STORED_THE_PROVIDED_SHAPEFILE!!!")			# path to wherever you store the shapefile
shapefile <- paste(HomeOfShapefile,"ne_110m_admin_0_countries_lakes.shp",sep="")		# country and lakes countours
world_shp <- readOGR(shapefile)

Agrid <- expand.grid(lon=lons,lat=lats)

#---------------------------------------------------------------------------------------
# define default plotting environment 

my.padding <- list(layout.heights = list(
top.padding = 0,
main.key.padding = 0,
key.axis.padding = 0,
axis.xlab.padding = 0,
xlab.key.padding = 0,
key.sub.padding = 0),
layout.widths = list(
left.padding = 0,
key.ylab.padding = 0,
ylab.axis.padding = 0,
axis.key.padding = 0,
right.padding = 0)
)

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure 1: Time series of continental-scale spatial averages of variables for RCP8.5, calculated from decadal averages of grid cells

message("Creating Figure 1")

paneltag <- c("a)","b)","c)","d)","e)","f)","g)","h)","i)")
varorder_plotting <- c(3,8,4,5,6,7,9,2,1)

graphics.off()
pdf("Figure1.pdf",width=9,height=7.5)
par(mfrow=c(3,3),oma=c(0,0,0,0),mar=c(4,4,1,1))

thickness <- 2
for(v in 1:nvar)
{
	vari <- varorder_plotting[v]
	
	yrange <- c(0,max(NaRV.omit(as.vector(vars_savg[vari,,]))))
	plot(-100,-100,xlim=c(1,13),ylim=yrange,xlab="",ylab=varlong[vari],xaxt='n')
	at1 <- seq(1,13,1)
	axis(side=1, at = at1, labels=dvs,las=0, col=NA, col.ticks=1 )
	lines(seq(1,13,1),vars_savg[vari,1, ],col="#8B1A1A",lwd=thickness)				# equilibrium with fire
	lines(seq(1,13,1),vars_savg[vari,2, ],col="#FF3030",lwd=thickness)				# transient with fire
	lines(seq(1,13,1),vars_savg[vari,5, ],col="#00688B",lwd=thickness)				# equilibrium without fire
	lines(seq(1,13,1),vars_savg[vari,6, ],col="#00BFFF",lwd=thickness)				# transient without fire
	for(t in 1:ntime)
	{
		points(t,vars_savg[vari,1,t],col="#8B1A1A",pch=16,cex=1.2)
		points(t,vars_savg[vari,2,t],col="#FF3030",pch=15,cex=1.2)
		points(t,vars_savg[vari,5,t],col="#00688B",pch=16,cex=1.2)
		points(t,vars_savg[vari,6,t],col="#00BFFF",pch=15,cex=1.2)
	}
	if(vari==3)
	{
		text(1,0.23*yrange[2],"-- Equilibrium with fire",col="#8B1A1A",pos=4)		
		text(1,0.16*yrange[2],"-- Transient with fire",col="#FF3030",pos=4)
		text(1,0.09*yrange[2],"-- Equilibrium no fire",col="#00688B",pos=4)
		text(1,0.02*yrange[2],"-- Transient no fire",col="#00BFFF",pos=4)
	}
	text(0.5,0.98*yrange[2],paneltag[v],pos=4, cex=1.2)
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure 2: Continental-scale spatial average of Euclidean distance between SDPs, for the four transient-equilibrium scenario pairings. Error bars
# represent standard deviation of spatial average in a given decade

message("Creating Figure 2")

yrange <- range(min(smean_edist-ssd_edist),max(smean_edist+ssd_edist))
scen_col <- c("#ED351E","#961B0C","#3FA5FB","#4033C4")

graphics.off()
	pdf("Figure2.pdf",width=4.3,height=4.3)
	par(mfrow=c(1,1),oma=c(0,0,0,0),mar=c(4,4,1,1))

	plot(-100,-100,xlim=c(1,13),ylim=c(yrange),ylab=c("Average Euclidean distance"),xlab="",xaxt='n',cex=1)	
	at1 <- seq(1,13,1)
	axis(side=1, at = at1, labels=dvs,las=0, col=NA, col.ticks=1 )	
	for(n in 1:(nscen/2))
	{
		lines(seq(1,13,1),smean_edist[n,],col=scen_col[n],lwd=2)
		for(t in 1:ntime)
		{
			arrows(t,smean_edist[n,t]-ssd_edist[n,t],t,smean_edist[n,t]+ssd_edist[n,t], code=3, angle=90, length=0.05, col=scen_col[n], lwd=1)
		}
	}
	text(1,4.9,"- RCP8.5 with fire",col=scen_col[1],pos=4)
	text(1,4.6,"- RCP4.5 with fire",col=scen_col[2],pos=4)
	text(1,5.5,"- RCP8.5 without fire",col=scen_col[3],pos=4)
	text(1,5.2,"- RCP4.5 without fire",col=scen_col[4],pos=4)	

graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure 3:  Spatial patterns of Euclidean distance between SDPs in RCP8.5 for three selected decades (2010-2019, 2050-2059, 2090-2099).
# Panels a), c) and e) represent distance between SDPs in simulations including fire (wifi), panels b), d) and f) show results from simulations
# excluding fire (nofi).

message("Creating Figure 3")

frange <- c(min(NaRV.omit(as.vector(edist))), max(NaRV.omit(as.vector(edist))))										# full range of values
range <- c(min(NaRV.omit(as.vector(edist))),quantile(NaRV.omit(as.vector(edist)),0.99))
cp_edist <- c(seq(range[1],range[2],(range[2]-range[1])/(length(dist_cpt)-1)),max(NaRV.omit(as.vector(edist))))
di <- c(5,9,13)	# decades of interest

at.brks <- seq(0,length(dist_cpt),1)
at.brks2 <-c(seq(0,length(dist_cpt),3),20)
cp_edist2 <- c(round(cp_edist[seq(1,length(cp_edist),3)],digits=2),expression(infinity))

lab1 <- c("a)","c)","e)")
lab2 <- c("b)","d)","f)")

slab1 <- "RCP8.5 wifi"
slab2 <- "RCP8.5 nofi"
dv <- c("2010s","2050s","2090s")

graphics.off()
pdf("Figure3.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(edist[,,wf85,di[t]] ~ lon * lat, data=Agrid, at=cp_edist, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks2,labels=(cp_edist2))), 
	col.regions=(dist_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))

    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(edist[,,nf85,di[t]] ~ lon * lat, data=Agrid, at=cp_edist, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks2,labels=(cp_edist2))), 
	col.regions=(dist_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)
	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure 4. Fractions of African area where a given state variable is the dominant variable with respect to Euclidean distance between SDPs,
# illustrated as time series stacks for the four scenario pairings between SDPs.

# make a time-series stack-plot of the dominant variables' fractions (using the colors used in the DomVars plots)

message("Creating Figure 4")

rcp <- c("RCP8.5 with fire","RCP4.5 with fire","RCP8.5 without fire","RCP4.5 without fire")

tmp <- array(0,c(ntime))
xcord <- c(1,1,1,8,1,1,1,1,3)
ycord <- c(0.15,0.31,0.37,0.5,0.56,0.75,0.87,0.93,0.97)
varlab <- c("Savanna tree cover","For. TC","TBM","C3:C4 grass ratio","Mean tree height","Maximum tree height","No. of tree individuals","Aboveground grass biomass","Total tree cover")
order <- c(1,3,2,4)

graphics.off()
pdf("Figure4.pdf",width=8.27,height=8.27)
par(mfrow=c(2,2),oma=c(0,0,0,0),mar=c(3,4,1,1))

for(n in 1:(nscen/2))
{
	scaler <- 1./sum(sum_dom_vars[ ,n,1])	# CAVE: totarea includes desert area, ought to re-scale to a fraction of 1 (focus on non-desert areas only)
	
	plot(-100,-100,xlim=c(1,13),ylim=c(0,1),ylab=c("Dominant variable area fraction"),xlab="",main=rcp[order[n]], xaxt='n')		# ,axes=FALSE
	at1 <- seq(1,13,1)
	axis(side=1, at = at1, labels=dvs,las=0, col=NA, col.ticks=1 )	
	axis(side=2, col=NA, col.ticks=1)	
	for(v in nvar:1)
	{
		for(t in 1:ntime)
		{
			tmp[t] <- sum(sum_dom_vars[1:v,order[n],t]) * scaler
		}
		polygon(c(1,seq(1,13,1),13),c(0,tmp,0),col=vars_cpt[v])
		if(n==1) { text(xcord[v], ycord[v], varlab[v], pos=4, cex=0.8) }
	}
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure 5. Continental-scale spatial average of lag time (panel a) and residual distance (panel b) between CDPs, for the four scenario pairings
# between CDPs. Error bars represent standard deviation of spatial averages in a given decade.

# plot the spatially-averaged time series of lagtimes

message("Creating Figure 5")

lyrange <- range(min(smean_lagtime-ssd_lagtime),max(smean_lagtime+ssd_lagtime))

tsl.pryr %<a-% {
	plot(-100,-100,xlim=c(1,13),ylim=c(lyrange),ylab=c("Avgerage lag time [decades]"),xlab="",xaxt='n')	
	at1 <- seq(1,13,1)
	axis(side=1, at = at1, labels=dvs,las=0, col=NA, col.ticks=1 )	
	for(n in 1:(nscen/2))
	{
		lines(seq(1,13,1),smean_lagtime[n,],col=scen_col[n],lwd=2)
		for(t in 1:ntime)
		{
			arrows(t,smean_lagtime[n,t]-ssd_lagtime[n,t],t,smean_lagtime[n,t]+ssd_lagtime[n,t], code=3, angle=90, length=0.05, col=scen_col[n], lwd=1)
		}
	}
	text(0.5,9.1,"a)",pos=4)
	x <- 1
	text(x,7.3,"- RCP8.5 with fire",col=scen_col[1],pos=4)
	text(x,6.7,"- RCP4.5 with fire",col=scen_col[2],pos=4)
	text(x,8.5,"- RCP8.5 without fire",col=scen_col[3],pos=4) 
	text(x,7.9,"- RCP4.5 without fire",col=scen_col[4],pos=4) 
}

# plot time series of spatially-averaged crosswide-decade pairing

yrange <- range(min(smean_edist-ssd_edist),max(smean_edist+ssd_edist))

tsc.pryr %<a-% {
	plot(-100,-100,xlim=c(1,13),ylim=c(yrange),ylab=c("Avgerage Euclidean distance"),xlab="",xaxt='n')	
	at1 <- seq(1,13,1)
	axis(side=1, at = at1, labels=dvs,las=0, col=NA, col.ticks=1 )	
	for(n in 1:(nscen/2))
	{
		lines(seq(1,13,1),smean_edist_cross[n,],col=scen_col[n],lwd=2)
		for(t in 1:ntime)
		{
			arrows(t,smean_edist_cross[n,t]-ssd_edist_cross[n,t],t,smean_edist_cross[n,t]+ssd_edist_cross[n,t], code=3, angle=90, length=0.05, col=scen_col[n], lwd=1)
		}
	}
	text(0.5,5.5,"b)",pos=4)	
}

graphics.off()
pdf("Figure5.pdf",width=8.27,height=4.3)
par(mfrow=c(1,2),oma=c(0,0,0,0),mar=c(4,4,1,1))
tsl.pryr
tsc.pryr
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure 6. Spatial patterns of lag time (decades) between CDPs for RCP8.5 with fire (panels a, c, e), and residual Euclidean distance between
# CDPs (panels b, d, f), for three selected decades (2010-2019, 2050-2059, 2090-2099).

# Lagtime and residual distance combined in one figure 

message("Creating Figure 6")

frange <- c(min(NaRV.omit(as.vector(MinDec_EuPast[,,,2,]))), max(NaRV.omit(as.vector(MinDec_EuPast[,,,2,]))))		# full range of values
range <- c(min(NaRV.omit(as.vector(MinDec_EuPast[,,,2,]))),quantile(NaRV.omit(as.vector(MinDec_EuPast[,,,2,])),0.99))
cp_EuPast <- c(seq(range[1],range[2],(range[2]-range[1])/(length(dist_cpt)-1)),max(NaRV.omit(as.vector(MinDec_EuPast[,,,2,]))))
di <- c(5,9,13)	# decades of interest

at.brks <- seq(0,length(dist_cpt),1)
at.brks2 <-c(seq(0,length(dist_cpt),3),20)
cp_EuPast2 <- c(round(cp_EuPast[seq(1,length(cp_EuPast),3)],digits=2),expression(infinity))

lab1 <- c("a)","c)","e)")
lab2 <- c("b)","d)","f)")

slab1 <- "RCP8.5 wifi"
dv <- c("2010s","2050s","2090s")
padded_labs <- c("  0","  1","  2","  3","  4","  5","  6","  7","  8","  9"," 10"," 11"," 12")

graphics.off()
pdf("Figure6.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	cpt <- lag2_cpt[1:di[t]]
	cp_dec <- seq(-0.5,di[t]-0.5,1)
	at.brks3 <- seq(0,12,1)

	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(9.8,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(Lagtime_EuPast[,,wf85,di[t]] ~ lon * lat, data=Agrid, at=cp_dec, pretty=T,  ylab="", xlab="",colorkey=list(width=0.75, at=cp_dec,labels=list(at=at.brks3,labels=padded_labs[0:(di[t])])),  
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))

    print(a, newpage = FALSE)
    popViewport(2)
   
    lab <- lab2[t] 
    tag <- paste(slab1," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(MinDec_EuPast[,,wf85,2,di[t]] ~ lon * lat, data=Agrid, at=cp_EuPast, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks2,labels=(cp_EuPast2))), 
	col.regions=(dist_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)
  
   
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure 7. Fractions of African area where a given variable is the dominant variable defining residual distance between CDPs, illustrated as
# time series stacks for the four scenario pairings between CDPs.

# make a time-series stack-plot of the dominant variables' fractions (using the colors used in the DomVars plots)

message("Creating Figure 7")

rcp <- c("8.5 with fire","4.5 with fire","8.5 without fire","4.5 without fire")

tmp <- array(0,c(ntime))
xcord <- c(1,2,3,8.5,1,4,5,2,1)
ycord <- c(0.15,0.27,0.305,0.4,0.5,0.64,0.75,0.9,0.975)
varlab <- c("Savanna tree cover","For. TC","TBM","C3:C4 grass ratio","Mean tree height","Maximum tree height","No. of tree individuals","Aboveground grass biomass","Total tree cover")
order <- c(1,3,2,4)

graphics.off()
pdf("Figure7.pdf",width=8.27,height=8.27)
par(mfrow=c(2,2),oma=c(0,0,0,0),mar=c(3,4,1,1))

for(n in 1:(nscen/2))
{
	scaler <- 1./sum(sum_dom_cvars[ ,n,1])	# CAVE: totarea includes desert area, re-scale to a fraction of 1 (focus on non-desert areas only)
	
	plot(-100,-100,xlim=c(1,13),ylim=c(0,1),ylab=c("Dominant variable area fraction"),xlab="",main=paste("RCP",rcp[order[n]],sep=""),xaxt='n')		# ,axes=FALSE
	at1 <- seq(1,13,1)
	axis(side=1, at = at1, labels=dvs,las=0, col=NA, col.ticks=1 )	
	axis(side=2, col=NA, col.ticks=1)	
	for(v in nvar:1)
	{
		for(t in 1:ntime)
		{
			tmp[t] <- sum(sum_dom_cvars[1:v,order[n],t]) * scaler
		}
		polygon(c(1,seq(1,13,1),13),c(0,tmp,0),col=vars_cpt[v])
		if(n==1) { text(xcord[v], ycord[v], varlab[v], pos=4, cex=0.8) }
	}
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure 8. Areas with only one biome type in all 13 decades (i.e., biome core areas) shown for each of the 8 scenarios. Areas that experience
# one or more biome transitions are masked out (white areas). Transient scenarios are indicated by label "t", equilibrium scenarios by label "e".

# figure showing the time-constant biome pixels for each scenario (8-panel-figure)

message("Creating Figure 8")

cap <- c("a)","b)","c)","d)","e)","f)","g)","h)")
biome_labels <- c("Desert","C3 grassland","C4 grassland","C3 Savanna","C4 Savanna","Woodland","Forest")
scen_vec <- c("RCP8.5e wifi","RCP8.5t wifi","RCP4.5e wifi","RCP4.5t wifi","RCP8.5e nofi","RCP8.5t nofi","RCP4.5e nofi","RCP4.5t nofi")
scen_vec2 <- c("RCP8.5 equilibrium with fire","RCP8.5 transient with fire","RCP4.5 equilibrium with fire","RCP4.5 transient with fire","RCP8.5 equilibrium no fire","RCP8.5 transient no fire","RCP4.5 equilibrium no fire","RCP4.5 transient no fire")
scen_vec3 <- c("RCP8.5e with fire","RCP8.5t with fire","RCP4.5e with fire","RCP4.5t with fire","RCP8.5e no fire","RCP8.5t no fire","RCP4.5e no fire","RCP4.5t no fire")
cpt <- biome_cpt1
cp_biomes <- seq(0.5,7.5,1)
at.brks <- seq(1,7,1)

xcords <- rep(0.05,7)
ycords <- rev(seq(length=7,from=0.1,by=0.04))

graphics.off()
pdf("Figure8.pdf",width=20/2.54, height=40/2.54)
pushViewport(viewport(width=unit(17.4,"cm"), height=unit(40,"cm"),layout=grid.layout(4, 2)))

for(n in 1:nscen)
{
    prow<- (n-1)%/%2+1
    pcol<- (n-1)%%2+1
    lab <- scen_vec3[n]
    pushViewport(viewport(layout.pos.col=pcol, layout.pos.row=prow))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
    a<-levelplot(time_stable_BT[,,n] ~ lon * lat, data=Agrid, at=cp_biomes,  ylab="", xlab="", col.regions=cpt, colorkey=FALSE,par.settings = my.padding) +
    latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) + latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=biome_labels, just="left",gp=gpar(fontsize=8,col="black"))) +
    latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=cpt))) +
    latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=lab,just="left",gp=gpar(fontsize=8,col="black"))) +
    latticeExtra::layer(grid.text(x=0.03,y=0.97,label=cap[n],just="left",gp=gpar(fontsize=12,col="black")))
    print(a, newpage = FALSE)
    popViewport(2)  
}
popViewport()
graphics.off()

#=========================================================
# Supplementary material figures
#=========================================================

# Figure S1. Time series of continental-scale spatial averages of variables for RCP4.5, calculated from decadal averages of grid cells

message("Creating Figure S1")

graphics.off()
pdf("Figure_S1.pdf",width=9,height=7.5)
par(mfrow=c(3,3),oma=c(0,0,0,0),mar=c(4,4,1,1))

thickness <- 2
for(v in 1:nvar)
{
	vari <- varorder_plotting[v]
	
	yrange <- c(0,max(NaRV.omit(as.vector(vars_savg[vari,,]))))
	plot(-100,-100,xlim=c(1,13),ylim=yrange,xlab="",ylab=varlong[vari],xaxt='n')
	at1 <- seq(1,13,1)
	axis(side=1, at = at1, labels=dvs,las=0, col=NA, col.ticks=1 )
	lines(seq(1,13,1),vars_savg[vari,3, ],col="#8B1A1A",lwd=thickness)				# equilibrium with fire
	lines(seq(1,13,1),vars_savg[vari,4, ],col="#FF3030",lwd=thickness)				# transient with fire
	lines(seq(1,13,1),vars_savg[vari,7, ],col="#00688B",lwd=thickness)				# equilibrium without fire
	lines(seq(1,13,1),vars_savg[vari,8, ],col="#00BFFF",lwd=thickness)				# transient without fire
	for(t in 1:ntime)
	{
		points(t,vars_savg[vari,3,t],col="#8B1A1A",pch=16,cex=1.2)
		points(t,vars_savg[vari,4,t],col="#FF3030",pch=15,cex=1.2)
		points(t,vars_savg[vari,7,t],col="#00688B",pch=16,cex=1.2)
		points(t,vars_savg[vari,8,t],col="#00BFFF",pch=15,cex=1.2)
	}
			if(vari==3)
	{
		text(1,0.23*yrange[2],"-- Equilibrium with fire",col="#8B1A1A",pos=4)
		text(1,0.16*yrange[2],"-- Transient with fire",col="#FF3030",pos=4)
		text(1,0.09*yrange[2],"-- Equilibrium no fire",col="#00688B",pos=4)
		text(1,0.02*yrange[2],"-- Transient no fire",col="#00BFFF",pos=4)
	}
text(0.5,0.98*yrange[2],paneltag[v],pos=4, cex=1.2)
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S2. Spatial patterns of Euclidean distance between SDPs in RCP4.5 for three selected decades (2010-2019, 2050-2059, 2090-2099).
# Panels a, c, and e represent distance between SDPs in simulations including fire, panels b, d and f are for SDPs from simulations excluding
# fire.

message("Creating Figure S2")

frange <- c(min(NaRV.omit(as.vector(edist))), max(NaRV.omit(as.vector(edist))))		# full range of values
range <- c(min(NaRV.omit(as.vector(edist))),quantile(NaRV.omit(as.vector(edist)),0.99))
cp_edist <- c(seq(range[1],range[2],(range[2]-range[1])/(length(dist_cpt)-1)),max(NaRV.omit(as.vector(edist))))

at.brks <- seq(0,length(dist_cpt),1)
at.brks2 <-c(seq(0,length(dist_cpt),3),20)
cp_edist2 <- c(round(cp_edist[seq(1,length(cp_edist),3)],digits=2),expression(infinity))

slab1 <- "RCP4.5 wifi"
slab2 <- "RCP4.5 nofi"

graphics.off()
pdf("Figure_S2.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(edist[,,wf45,di[t]] ~ lon * lat, data=Agrid, at=cp_edist, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks2,labels=(cp_edist2))), 
	col.regions=(dist_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))

    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(edist[,,nf45,di[t]] ~ lon * lat, data=Agrid, at=cp_edist, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks2,labels=(cp_edist2))), 
	col.regions=(dist_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S3. Decay of influence on full Euclidean distance between SDPs according to variable rank, and separated by variable identity. The
# second-most influential variable had substantially less influence on full Euclidean distance than the dominant variable, and influence of 
# higher-ranked variables rapidly declined.

message("Creating Figure S3")

tag <- c("a)","b)","c)","d)")
rcp_long <- c("8.5 with fire","4.5 with fire","8.5 without fire","4.5 without fire")

graphics.off()
pdf("Figure_S3.pdf",width=8.27,height=8.27)
par(mfrow=c(2,2),oma=c(0,0,0,0),mar=c(4,4,1,1))

yrange <- c(min(as.vector(TAvg_InflDecay-TSD_InflDecay)),max(as.vector(TAvg_InflDecay+TSD_InflDecay)))

for(n in 1:(nscen/2))
{
	plot(-100,-100,xlim=c(1,nlevel),ylim=yrange,ylab=c("% Deviance from full Euclidean distance"),xlab="Influence rank")	

	for(v in 1:nvar)
	{
		lines(seq(1,nlevel,1),TAvg_InflDecay[v,,n], col=vars_cpt[v], lwd=2)
		for(l in 1:nlevel)
		{
			arrows(l,TAvg_InflDecay[v,l,n]-TSD_InflDecay[v,l,n],l,TAvg_InflDecay[v,l,n]+TSD_InflDecay[v,l,n], code=3, angle=90, length=0.05, col=vars_cpt[v], lwd=0.5)
		}
		if(n==1)
		{
			points(6,0.955*yrange[2]-(v-1)*(yrange[2]-yrange[1])/(nvar*2),pch=15,col=vars_cpt[v],cex=1.2)
			text(6,0.95*yrange[2]-(v-1)*(yrange[2]-yrange[1])/(nvar*2), varlab2[v], pos=4,cex=0.8)
		}	
	}
	text(1,1*yrange[2],paste(tag[n]," RCP",rcp_long[n],sep=""),pos=4)	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S4. Spatial pattern of dominant variables with respect to Euclidean distance between SDPs for RCP8.5 for the three reference decades.
# Panels a, c, and e show the spatial pattern for RCP8.5 with fire, panels b, d, and f the pattern for RCP8.5 without fire.

message("Creating Figure S4")

level <- 1
cp_vars <- seq(0.5,9.5,1)
at.brks <- seq(1,9,1)

xcords <- rep(0.05,9)
ycords <- rev(seq(length=9,from=0.1,by=0.04))

lab1 <- c("a)","c)","e)")
lab2 <- c("b)","d)","f)")

slab1 <- "RCP8.5 wifi"
slab2 <- "RCP8.5 nofi"
# dv <- c("2010s","2050s","2090s")

graphics.off()
pdf("Figure_S4.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(17.4,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(sort_edist_vars[,,level,wf85,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=FALSE, 
	col.regions=(vars_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=varlab2, just="left",gp=gpar(fontsize=7,col="black"))) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=vars_cpt))) +
	latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=tag,just="left",gp=gpar(fontsize=7,col="black",fontface="bold")))
    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(sort_edist_vars[,,level,nf85,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=FALSE, 
	col.regions=(vars_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=varlab2, just="left",gp=gpar(fontsize=7,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=vars_cpt))) +
	latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=tag,just="left",gp=gpar(fontsize=7,col="black",fontface="bold")))	
	print(b, newpage = FALSE)
	popViewport(2)	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S5. Spatial pattern of dominant variables with respect to Euclidean distance between SDPs for RCP4.5 for the three reference decades.
# Panels a, c, and e show the spatial pattern for RCP4.5 with fire, panels b, d, and f the pattern for RCP4.5 without fire.

message("Creating Figure S5")

slab1 <- "RCP4.5 wifi"
slab2 <- "RCP4.5 nofi"

graphics.off()
pdf("Figure_S5.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(17.4,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(sort_edist_vars[,,level,wf45,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=FALSE, 
	col.regions=(vars_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=varlab2, just="left",gp=gpar(fontsize=7,col="black"))) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=vars_cpt))) +
	latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=tag,just="left",gp=gpar(fontsize=7,col="black",fontface="bold")))
    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(sort_edist_vars[,,level,nf45,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=FALSE, 
	col.regions=(vars_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=varlab2, just="left",gp=gpar(fontsize=7,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=vars_cpt))) +
	latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=tag,just="left",gp=gpar(fontsize=7,col="black",fontface="bold")))	
	print(b, newpage = FALSE)
	popViewport(2)	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S6. Percent deviance from the full Euclidean distance caused by the dominant variable, for SDPs, by identity of most influential
# variable (colored boxes) and across all variables irrespective of identity (grey box). ST: savanna tree cover; FT: forest tree cover; TB:
# aboveground tree biomass; C3 :C4: C3 to C4 grass ratio; MH: mean tree height; MaH: maximum tree height; IndT: number of tree individuals;
# GB: aboveground grass biomass; TC: total tree cover; ALL: all variables combined; Boxes indicate first and third quartiles, the black line
# the median, the black star the mean value, and whiskers extend to 1.5 times the interquartile range. Percentage values of dominant variables
# were combined across all decades.

# make boxplots of PDomVar for each variable, across all pixels where that variable is dominant, lumped across all time slices

message("Creating Figure S6")

dat <- list()
long <- list()
lab <- c("a)","b)","c)","d)")
vs <- c("ST","FT","TB","C3:C4","MH","MaH","IndT","GB","TC","ALL")
title <- c("RCP8.5 with fire","RCP4.5 with fire","RCP8.5 without fire","RCP4.5 without fire")

graphics.off()
pdf("Figure_S6.pdf",width=10.8,height=7.7)
par(mfrow=c(2,2),oma=c(0,0,0,0),mar=c(4,4,1,1))

	for(n in 1:(nscen/2))
	{
		PDAT <- list()		# make one list entry per variable, i.e., a list of length nvar; recycle for each scenario after plotting the boxplots
		for(v in 1:nvar)
		{
			ht <- NULL
			for(t in 1:ntime)
			{
				h <- NULL
				for(x in 1:nlon)
				{
				
					mask <- which(sort_edist_vars[x,,1,n,t]==v)
					h <- c(h,spdiff_edist_vars[x,mask,1,n,t])
				}
				ht <- c(ht,h)
			}
			PDAT[[v]] <- ht
		}
		PDAT[[nvar+1]] <- c(PDAT[[1]],PDAT[[2]],PDAT[[3]],PDAT[[4]],PDAT[[5]],PDAT[[6]],PDAT[[7]],PDAT[[8]],PDAT[[9]])
		dat[[n]] <- data.frame(lapply(PDAT,"length<-",max(lengths(PDAT))))
		long[[n]] <- melt(dat[[n]])
		
		plot(value ~ variable, data=long[[n]], xlab="", xaxt='n', ylab="% deviance from full Euclidean distance", outpch=20, outcex=0.15, outcol=c(vars_cpt,"grey"), col=adjustcolor(c(vars_cpt,"grey"), alpha=0.75))
		at1 <- seq(1,(nvar+1),1)
		axis(side=1, at = at1, labels=vs,las=0, col=NA, col.ticks=1,cex=0.5 )	
		text(0.1,99,paste(lab[n],title[n],sep=" "),col="black",pos=4)
		means <- aggregate(value ~ variable, long[[n]], mean)
		points(1:10, means$value, pch=8, col="black")
	}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S7. Spatial pattern of percent deviance from full Euclidean distance caused by the dominant variable for RCP8.5, for SDPs. Panels a,
# c and e are for SDPs from simulations including fire, panels b, d and f for SDPs from simulations without fire.

message("Creating Figure S7")

level <- 1
frange <- range(NaRV.omit(as.vector(spdiff_edist_vars[,,level,,])))
range <- c(min(NaRV.omit(as.vector(spdiff_edist_vars[,,level,,]))), quantile(NaRV.omit(as.vector(spdiff_edist_vars[,,level,,])),0.99))
cpt <- perc_cpt
cp_vars <- seq(frange[1],frange[2],(frange[2]-frange[1])/length(cpt))
if(frange[2]-(frange[2]-frange[1])/length(cpt) > range[2])
{
	cp_vars <- c(seq(range[1],range[2],(range[2]-range[1])/(length(cpt)-1)),max(NaRV.omit(as.vector(spdiff_edist_vars[,,level,,]))))
}
at.brks <- seq(0,length(cpt),1)

lab1 <- c("a)","c)","e)")
lab2 <- c("b)","d)","f)")

slab1 <- "RCP8.5 wifi"
slab2 <- "RCP8.5 nofi"

graphics.off()
pdf("Figure_S7.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(spdiff_edist_vars[,,level,wf85,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks,labels=round(cp_vars,digits=1))), 
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))

    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(spdiff_edist_vars[,,level,nf85,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks,labels=round(cp_vars,digits=1))), 
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)
	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S8. Spatial pattern of percent deviance from full Euclidean distance caused by the dominant variable for RCP4.5, for SDPs. Panels a,
# c and e are for SDPs from simulations including fire, panels b, d and f for SDPs from simulations without fire.

message("Creating Figure S8")

slab1 <- "RCP4.5 wifi"
slab2 <- "RCP4.5 nofi"

graphics.off()
pdf("Figure_S8.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(spdiff_edist_vars[,,level,wf45,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks,labels=round(cp_vars,digits=1))), 
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))

    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(spdiff_edist_vars[,,level,nf45,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks,labels=round(cp_vars,digits=1))), 
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)
	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S9. Spatial patterns of lag time between CDPs for RCP8.5 without fire (panels a, c and e), and residual Euclidean distance between
# CDPs (panels b, d and f), for three selected decades (2010-2019, 2050-2059, 2090-2099).

message("Creating Figure S9")

frange <- c(min(NaRV.omit(as.vector(MinDec_EuPast[,,,2,]))), max(NaRV.omit(as.vector(MinDec_EuPast[,,,2,]))))		# full range of values
range <- c(min(NaRV.omit(as.vector(MinDec_EuPast[,,,2,]))),quantile(NaRV.omit(as.vector(MinDec_EuPast[,,,2,])),0.99))
cp_EuPast <- c(seq(range[1],range[2],(range[2]-range[1])/(length(dist_cpt)-1)),max(NaRV.omit(as.vector(MinDec_EuPast[,,,2,]))))

at.brks <- seq(0,length(dist_cpt),1)
at.brks2 <-c(seq(0,length(dist_cpt),3),20)
cp_EuPast2 <- c(round(cp_EuPast[seq(1,length(cp_EuPast),3)],digits=2),expression(infinity))

slab1 <- "RCP8.5 nofi"

graphics.off()
pdf("Figure_S9.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	cpt <- lag2_cpt[1:di[t]]
	cp_dec <- seq(-0.5,di[t]-0.5,1)
	at.brks3 <- seq(0,12,1)

	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(9.8,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(Lagtime_EuPast[,,nf85,di[t]] ~ lon * lat, data=Agrid, at=cp_dec, pretty=T,  ylab="", xlab="",colorkey=list(width=0.75, at=cp_dec,labels=list(at=at.brks3,labels=padded_labs[0:(di[t])])),  
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))

    print(a, newpage = FALSE)
    popViewport(2)
   
    lab <- lab2[t] 
    tag <- paste(slab1," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(MinDec_EuPast[,,nf85,2,di[t]] ~ lon * lat, data=Agrid, at=cp_EuPast, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks2,labels=(cp_EuPast2))), 
	col.regions=(dist_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)  
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S10. Spatial patterns of lag time between CDPs for RCP4.5 with fire (panels a, c and e), and residual Euclidean distance between
# CDPs (panels b, d and f), for three selected decades (2010-2019, 2050-2059, 2090-2099).

message("Creating Figure S10")

slab1 <- "RCP4.5 wifi"

graphics.off()
pdf("Figure_S10.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	cpt <- lag2_cpt[1:di[t]]
	cp_dec <- seq(-0.5,di[t]-0.5,1)
	at.brks3 <- seq(0,12,1)

	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(9.8,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(Lagtime_EuPast[,,wf45,di[t]] ~ lon * lat, data=Agrid, at=cp_dec, pretty=T,  ylab="", xlab="",colorkey=list(width=0.75, at=cp_dec,labels=list(at=at.brks3,labels=padded_labs[0:(di[t])])),  
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))

    print(a, newpage = FALSE)
    popViewport(2)
   
    lab <- lab2[t] 
    tag <- paste(slab1," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(MinDec_EuPast[,,wf45,2,di[t]] ~ lon * lat, data=Agrid, at=cp_EuPast, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks2,labels=(cp_EuPast2))), 
	col.regions=(dist_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)  
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S11. Spatial patterns of lag time between CDPs for RCP4.5 without fire (panels a, c and e), and residual Euclidean distance between
# CDPs (panels b, d and e), for three selected decades (2010-2019, 2050-2059, 2090-2099).

message("Creating Figure S11")

slab1 <- "RCP4.5 nofi"

graphics.off()
pdf("Figure_S11.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	cpt <- lag2_cpt[1:di[t]]
	cp_dec <- seq(-0.5,di[t]-0.5,1)
	at.brks3 <- seq(0,12,1)

	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(9.8,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(Lagtime_EuPast[,,nf45,di[t]] ~ lon * lat, data=Agrid, at=cp_dec, pretty=T,  ylab="", xlab="",colorkey=list(width=0.75, at=cp_dec,labels=list(at=at.brks3,labels=padded_labs[0:(di[t])])),  
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))

    print(a, newpage = FALSE)
    popViewport(2)
   
    lab <- lab2[t] 
    tag <- paste(slab1," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(MinDec_EuPast[,,nf45,2,di[t]] ~ lon * lat, data=Agrid, at=cp_EuPast, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks2,labels=(cp_EuPast2))), 
	col.regions=(dist_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)  
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S12. Residual distance between CDPs shown against lag time, irrespective of the transient decade in which these pairs occur. Boxes
# indicate first and third quartiles, the black line the median, and whiskers extend to 1.5 times the interquartile range.

# plot remaining Euclidean distance as boxplots against lagtime

message("Creating Figure S12")

dat <- list()
long <- list()
lab <- c("a)","b)","c)","d)")

graphics.off()
pdf("Figure_S12.pdf",width=8.27, height=5.9)
par(mfrow=c(2,2),oma=c(0,0,0,0),mar=c(4,4,1,1))

for(n in 1:(nscen/2))
{
	E1 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,1]))
	E2 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,2]))
	E3 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,3]))
	E4 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,4]))
	E5 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,5]))
	E6 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,6]))
	E7 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,7]))
	E8 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,8]))
	E9 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,9]))
	E10 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,10]))
	E11 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,11]))
	E12 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,12]))
	E13 <- NaRV.omit(as.vector(MinDec_EuPast[,,n,2,13]))

	dat[[n]] <- data.frame(E1,E2,E3,E4,E5,E6,E7,E8,E9,E10,E11,E12,E13)

	long[[n]] <- melt(dat[[n]])

	plot(value ~ variable, data=long[[n]], xlab="Lag time [decades]", xaxt='n', ylab="Residual Euclidean distance", ylim=c(0,10), outpch=20, outcex=0.15, outcol=lag2_cpt, col=adjustcolor(lag2_cpt, alpha=0.75))
	at1 <- seq(1,13,2)
	axis(side=1, at = at1, labels=at1,las=0, col=NA, col.ticks=1 )	
	text(0.1,9.8,paste(lab[n],title[n],sep=" "),col="black",pos=4)
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S13. Decay of influence on full Euclidean distance between CDPs according to variable rank, and separated by variable identity.
# The second-most influential variable had substantially less influence on full Euclidean distance than the dominant variable, and influence of
# higher-ranked variables rapidly declined.

message("Creating Figure S13")

tag <- c("a)","b)","c)","d)")
yrange <- c(min(as.vector(TAvg_InflDecay-TSD_InflDecay)),max(as.vector(TAvg_InflDecay+TSD_InflDecay)))

graphics.off()
pdf("Figure_S13.pdf",width=8.27,height=8.27)
par(mfrow=c(2,2),oma=c(0,0,0,0),mar=c(4,4,1,1))

for(n in 1:(nscen/2))
{
	plot(-100,-100,xlim=c(1,nlevel),ylim=yrange,ylab=c("% Deviance from full Euclidean distance"),xlab="Influence rank")	

	for(v in 1:nvar)
	{
		lines(seq(1,nlevel,1),TAvg_InflDecay_cross[v,,n], col=vars_cpt[v], lwd=2)
		for(l in 1:nlevel)
		{
			arrows(l,TAvg_InflDecay_cross[v,l,n]-TSD_InflDecay_cross[v,l,n],l,TAvg_InflDecay_cross[v,l,n]+TSD_InflDecay_cross[v,l,n], code=3, angle=90, length=0.05, col=vars_cpt[v], lwd=0.5)
		}
		if(n==1)
		{
			points(6,0.955*yrange[2]-(v-1)*(yrange[2]-yrange[1])/(nvar*2),pch=15,col=vars_cpt[v],cex=1.2)
			text(6,0.95*yrange[2]-(v-1)*(yrange[2]-yrange[1])/(nvar*2), varlab2[v], pos=4,cex=0.8)
		}		
	}
	text(1,1*yrange[2],paste(tag[n]," RCP",rcp_long[n],sep=""),pos=4)	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S14. Spatial pattern of dominant variables with respect to Euclidean distance between CDPs for RCP8.5 for the three reference
# decades. Panels a, c and e show the spatial pattern for RCP8.5 with fire, panels b, d and f the pattern for RCP8.5 without fire.

message("Creating Figure S14")

level <- 1
cp_vars <- seq(0.5,9.5,1)
at.brks <- seq(1,9,1)

xcords <- rep(0.05,9)
ycords <- rev(seq(length=9,from=0.1,by=0.04))

slab1 <- "RCP8.5 wifi"
slab2 <- "RCP8.5 nofi"

graphics.off()
pdf("Figure_S14.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(17.4,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(sort_edist_cvars[,,level,wf85,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=FALSE, 
	col.regions=(vars_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=varlab2, just="left",gp=gpar(fontsize=7,col="black"))) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=vars_cpt))) +
	latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=tag,just="left",gp=gpar(fontsize=7,col="black",fontface="bold")))
    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(sort_edist_cvars[,,level,nf85,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=FALSE, 
	col.regions=(vars_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=varlab2, just="left",gp=gpar(fontsize=7,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=vars_cpt))) +
	latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=tag,just="left",gp=gpar(fontsize=7,col="black",fontface="bold")))	
	print(b, newpage = FALSE)
	popViewport(2)
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S15. Spatial pattern of dominant variables with respect to Euclidean distance between CDPs for RCP4.5 for the three reference
# decades. Panels a, c and e show the spatial pattern for RCP4.5 with fire, panels b, d and f the pattern for RCP4.5 without fire.

message("Creating Figure S15")

slab1 <- "RCP4.5 wifi"
slab2 <- "RCP4.5 nofi"

graphics.off()
pdf("Figure_S15.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(17.4,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(sort_edist_cvars[,,level,wf45,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=FALSE, 
	col.regions=(vars_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=varlab2, just="left",gp=gpar(fontsize=7,col="black"))) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=vars_cpt))) +
	latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=tag,just="left",gp=gpar(fontsize=7,col="black",fontface="bold")))
    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(8.7,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(sort_edist_cvars[,,level,nf45,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=FALSE, 
	col.regions=(vars_cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=xcords+0.04,y=ycords,label=varlab2, just="left",gp=gpar(fontsize=7,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.points(x=xcords,y=ycords,pch=rep(15,7),size=unit(8,"pt"),default.units = "npc",gp=gpar(col=vars_cpt))) +
	latticeExtra::layer(grid.text(x=xcords[1]-0.02,y=ycords[1]+0.05,label=tag,just="left",gp=gpar(fontsize=7,col="black",fontface="bold")))	
	print(b, newpage = FALSE)
	popViewport(2)
	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S16. Percent deviance from the full Euclidean distance caused by the dominant variable, for CDPs, by identity of most influential
# variable (colored boxes) and across all variables irrespective of identity (grey box). ST: savanna tree cover; FT: forest tree cover; TB:
# aboveground tree biomass; C3 :C4: C3 to C4 grass ratio; MH: mean tree height; MaH: maximum tree height; IndT: number of tree individuals;
# GB: aboveground grass biomass; TC: total tree cover; ALL: all variables combined; Boxes indicate first and third quartiles, the black line
# the median, the black star the mean value, and whiskers extend to 1.5 times the interquartile range. Percentage values of dominant variables
# were combined across all decades.

message("Creating Figure S16")

dat <- list()
long <- list()
lab <- c("a)","b)","c)","d)")

graphics.off()
pdf("Figure_S16.pdf",width=10.8,height=7.7)
par(mfrow=c(2,2),oma=c(0,0,0,0),mar=c(4,4,1,1))

	for(n in 1:(nscen/2))
	{
		PDAT <- list()		# make one list entry per variable, i.e., a list of length nvar; recycle for each scenario after plotting the boxplots
		for(v in 1:nvar)
		{
			ht <- NULL
			for(t in 1:ntime)
			{
				h <- NULL
				for(x in 1:nlon)
				{
				
					mask <- which(sort_edist_cvars[x,,1,n,t]==v)
					h <- c(h,spdiff_edist_cvars[x,mask,1,n,t])
				}
				ht <- c(ht,h)
			}
			PDAT[[v]] <- ht
		}
		PDAT[[nvar+1]] <- c(PDAT[[1]],PDAT[[2]],PDAT[[3]],PDAT[[4]],PDAT[[5]],PDAT[[6]],PDAT[[7]],PDAT[[8]],PDAT[[9]])
		dat[[n]] <- data.frame(lapply(PDAT,"length<-",max(lengths(PDAT))))
		long[[n]] <- melt(dat[[n]])
		
		plot(value ~ variable, data=long[[n]], xlab="", xaxt='n', ylab="% deviance from full Euclidean distance", outpch=20, outcex=0.15, outcol=c(vars_cpt,"grey"), col=adjustcolor(c(vars_cpt,"grey"), alpha=0.75))
		at1 <- seq(1,(nvar+1),1)
		axis(side=1, at = at1, labels=vs,las=0, col=NA, col.ticks=1,cex=0.5 )	
		text(0.1,99,paste(lab[n],title[n],sep=" "),col="black",pos=4)
		means <- aggregate(value ~ variable, long[[n]], mean)
		points(1:10, means$value, pch=8, col="black")
	}

graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S17. Spatial pattern of percent deviance from full Euclidean distance caused by the dominant variable for RCP8.5, for CDPs. Panels
# a, c and e refer to CDPs from simulations including fire, panels b, d and f to CDPs from simulations without fire.

message("Creating Figure S17")

level <- 1
frange <- range(NaRV.omit(as.vector(spdiff_edist_cvars[,,level,,])))
range <- c(min(NaRV.omit(as.vector(spdiff_edist_cvars[,,level,,]))), quantile(NaRV.omit(as.vector(spdiff_edist_cvars[,,level,,])),0.99))
cpt <- perc_cpt
cp_vars <- seq(frange[1],frange[2],(frange[2]-frange[1])/length(cpt))
if(frange[2]-(frange[2]-frange[1])/length(cpt) > range[2])
{
	cp_vars <- c(seq(range[1],range[2],(range[2]-range[1])/(length(cpt)-1)),max(NaRV.omit(as.vector(spdiff_edist_cvars[,,level,,]))))
}
at.brks <- seq(0,length(cpt),1)

slab1 <- "RCP8.5 wifi"
slab2 <- "RCP8.5 nofi"

graphics.off()
pdf("Figure_S17.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(spdiff_edist_cvars[,,level,wf85,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks,labels=round(cp_vars,digits=1))), 
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(spdiff_edist_cvars[,,level,nf85,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks,labels=round(cp_vars,digits=1))), 
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S18. Spatial pattern of percent deviance from full Euclidean distance caused by the dominant variable for RCP4.5, for CDPs. Panels
# a, c and e refer to CDPs from simulations including fire, panels b, d and f to CDPs from simulations without fire.

message("Creating Figure S18")

slab1 <- "RCP4.5 wifi"
slab2 <- "RCP4.5 nofi"

graphics.off()
pdf("Figure_S18.pdf",width=20/2.54, height=30/2.54)
pushViewport(viewport(width=unit(20,"cm"), height=unit(30,"cm"),layout=grid.layout(3, 2)))

for(t in 1:length(di))
{
	lab <- lab1[t]
	tag <- paste(slab1," ",dv[t],sep="")
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	a <- levelplot(spdiff_edist_cvars[,,level,wf45,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks,labels=round(cp_vars,digits=1))), 
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
    print(a, newpage = FALSE)
    popViewport(2)
     
    lab <- lab2[t] 
    tag <- paste(slab2," ",dv[t],sep="") 
	pushViewport(viewport(layout.pos.col=2, layout.pos.row=t))
    pushViewport(viewport(width=unit(10,"cm"), height=unit(10,"cm"), clip=TRUE))
	b <- levelplot(spdiff_edist_cvars[,,level,nf45,di[t]] ~ lon * lat, data=Agrid, at=cp_vars, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=at.brks,labels=list(at=at.brks,labels=round(cp_vars,digits=1))), 
	col.regions=(cpt),par.settings = my.padding) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.05,y=0.05,label=tag,just="left",gp=gpar(fontsize=10,col="black")))
	print(b, newpage = FALSE)
	popViewport(2)	
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S19. Fractions of African area covered by specific biome types, as time series stacks.

message("Creating Figure S19")

tmp <- array(0,c(ntime))
ypos <- c(0.1,0.25,0.29,0.33,0.38,0.65,0.9)

graphics.off()
pdf("Figure_S19.pdf",width=6.13,height=11.6)
par(mfrow=c(4,2),oma=c(0,0,0,0),mar=c(2,4,1,1))

for(n in 1:(nscen))
{
	plot(-100,-100,xlim=c(1,13),ylim=c(0,1),ylab=c("Biome fraction"),xlab="",xaxt='n')	
	at1 <- seq(1,13,1)
	axis(side=1, at = at1, labels=dvs,las=0, col=NA, col.ticks=1 )	
	axis(side=2, col=NA, col.ticks=1)	
	for(b in nbiome:1)
	{
		for(t in 1:ntime)
		{
			tmp[t] <- sum(BAF[1:b,n,t])
		}
		polygon(c(1,seq(1,13,1),13),c(0,tmp,0),col=biome_cpt1[b])
		if(n==1) { text(10,ypos[b],(biome_labels[b]),pos=4,cex=0.8) }
	}
	text(1.,0.95,paste(cap[n]," ",scen_vec2[n],sep=""),pos=4)
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S20. Overview showing the number of biome types assumed by a given grid cell (left column), the number of biome changes
# experienced by a given grid cell over the course of 13 decades (central column), and the ratio between number of biome changes experienced
# by a given grid cell and the number of biome types assumed by that grid cell (right column), for RCP8.5 simulation scenarios. A large ratio
# between number of biome changes and number of biome types assumed indicates a grid cell is flickering back and forth between two or more
# biome types, i.e., the transition is less definite than at a low ratio.

message("Creating Figure S20")

tag <- c("a)","b)","c)","d)","e)","f)","g)","h)","i)","j)","k)","l)")
scen <- c("RCP8.5e with fire","RCP8.5t with fire","RCP8.5e no fire","RCP8.5t no fire")
cp_Nobt <- seq(0.5,6.5,1)
at.brks1 <- seq(1,6,1)

cp_NoChBt <- seq(-0.5,12.5,1)
at.brks2 <- seq(0,12,1)

cp_ratio_BT <- seq(0,5.5,0.5)
at.brks3 <- seq(0,5.5,0.5)

graphics.off()
pdf("Figure_S20.pdf",width=29.1/2.54, height=35/2.54)
pushViewport(viewport(width=unit(29.1,"cm"), height=unit(35,"cm"),layout=grid.layout(4,3)))
prow <- 1

for(n in c(1,2,5,6))		
{
	c <- (prow-1)*3 + 1
	lab1 <- tag[c]
	lab2 <- scen[prow]
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=prow))
    pushViewport(viewport(width=unit(9.7,"cm"), height=unit(10,"cm"), clip=TRUE))
    a<-levelplot(No_BT[,,n] ~ lon * lat, data=Agrid, at=cp_Nobt, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=cp_Nobt,labels=list(at=at.brks1,labels=at.brks1)), 
	col.regions= NoBT_cpt) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab1,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.02,y=0.05,label="No. of biome types",just="left",gp=gpar(fontsize=8,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.02,y=0.1,label=lab2,just="left",gp=gpar(fontsize=8,col="black")))
    print(a, newpage = FALSE)
    popViewport(2)

	c <- (prow-1)*3 + 2
	lab1 <- tag[c]	
    pushViewport(viewport(layout.pos.col=2, layout.pos.row=prow))
    pushViewport(viewport(width=unit(9.7,"cm"), height=unit(10,"cm"), clip=TRUE))
    a<-levelplot(No_BT_changes[,,n] ~ lon * lat, data=Agrid, at=cp_NoChBt, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=cp_NoChBt,labels=list(at=at.brks2,labels=at.brks2)), 
	col.regions=lag2_cpt) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab1,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.02,y=0.05,label="No. of biome changes",just="left",gp=gpar(fontsize=8,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.02,y=0.1,label=lab2,just="left",gp=gpar(fontsize=8,col="black")))		
    print(a, newpage = FALSE)
    popViewport(2)

	c <- (prow-1)*3 + 3
	lab1 <- tag[c]	
    pushViewport(viewport(layout.pos.col=3, layout.pos.row=prow))
    pushViewport(viewport(width=unit(9.7,"cm"), height=unit(10,"cm"), clip=TRUE))
    a<-levelplot(Ratio_BT[,,n] ~ lon * lat, data=Agrid, at=cp_ratio_BT, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=cp_ratio_BT,labels=list(at=at.brks3,labels=at.brks3)), 
	col.regions=ratio_cpt) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab1,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.02,y=0.05,label="No. changes/No. types",just="left",gp=gpar(fontsize=8,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.02,y=0.1,label=lab2,just="left",gp=gpar(fontsize=8,col="black")))		
    print(a, newpage = FALSE)
    popViewport(2)

	prow <- prow + 1
}
graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure S21. Overview showing the number of biome types assumed by a given grid cell (left column), the number of biome changes
# experienced by a given grid cell over the course of 13 decades (central column), and the ratio between number of biome changes experienced
# by a given grid cell and the number of biome types assumed by that grid cell (right column), for RCP4.5 simulation scenarios. A large ratio
# between number of biome changes and number of biome types assumed indicates a grid cell is flickering back and forth between two or more
# biome types, i.e., the transition is less definite than at a low ratio.

message("Creating Figure S21")

graphics.off()
pdf("Figure_S21.pdf",width=29.1/2.54, height=35/2.54)
pushViewport(viewport(width=unit(29.1,"cm"), height=unit(35,"cm"),layout=grid.layout(4,3)))

scen <- c("RCP4.5e with fire","RCP4.5t with fire","RCP4.5e no fire","RCP4.5t no fire")

prow <- 1
for(n in c(3,4,7,8))		
{
	c <- (prow-1)*3 + 1
	lab1 <- tag[c]
	lab2 <- scen[prow]
    pushViewport(viewport(layout.pos.col=1, layout.pos.row=prow))
    pushViewport(viewport(width=unit(9.7,"cm"), height=unit(10,"cm"), clip=TRUE))
    a<-levelplot(No_BT[,,n] ~ lon * lat, data=Agrid, at=cp_Nobt, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=cp_Nobt,labels=list(at=at.brks1,labels=at.brks1)), 
	col.regions= NoBT_cpt) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab1,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.02,y=0.05,label="No. of biome types",just="left",gp=gpar(fontsize=8,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.02,y=0.1,label=lab2,just="left",gp=gpar(fontsize=8,col="black")))
    print(a, newpage = FALSE)
    popViewport(2)

	c <- (prow-1)*3 + 2
	lab1 <- tag[c]	
    pushViewport(viewport(layout.pos.col=2, layout.pos.row=prow))
    pushViewport(viewport(width=unit(9.7,"cm"), height=unit(10,"cm"), clip=TRUE))
    a<-levelplot(No_BT_changes[,,n] ~ lon * lat, data=Agrid, at=cp_NoChBt, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=cp_NoChBt,labels=list(at=at.brks2,labels=at.brks2)), 
	col.regions=lag2_cpt) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab1,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.02,y=0.05,label="No. of biome changes",just="left",gp=gpar(fontsize=8,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.02,y=0.1,label=lab2,just="left",gp=gpar(fontsize=8,col="black")))		
    print(a, newpage = FALSE)
    popViewport(2)

	c <- (prow-1)*3 + 3
    pushViewport(viewport(layout.pos.col=3, layout.pos.row=prow))
    pushViewport(viewport(width=unit(9.7,"cm"), height=unit(10,"cm"), clip=TRUE))
    a<-levelplot(Ratio_BT[,,n] ~ lon * lat, data=Agrid, at=cp_ratio_BT, pretty=T,  ylab="", xlab="", colorkey=list(width=0.75, at=cp_ratio_BT,labels=list(at=at.brks3,labels=at.brks3)), 
	col.regions=ratio_cpt) + latticeExtra::layer(sp.lines(world_shp, col="black", lwd=0.5)) +
	latticeExtra::layer(grid.text(x=0.03,y=0.97,label=lab1,just="left",gp=gpar(fontsize=12,col="black"))) +
	latticeExtra::layer(grid.text(x=0.02,y=0.05,label="No. changes/No. types",just="left",gp=gpar(fontsize=8,col="black"))) +	
	latticeExtra::layer(grid.text(x=0.02,y=0.1,label=lab2,just="left",gp=gpar(fontsize=8,col="black")))		
    print(a, newpage = FALSE)
    popViewport(2)

	prow <- prow + 1
}
graphics.off()

#=====================================================================================================
# Sankey diagrams illustrating biome change over time, as well as biome differences between scenarios
#=====================================================================================================

bnames1 <- c("Desert","C3-grassland","C4-grassland","C3-Savanna","C4-Savanna","Woodland","Forest")
bnames2 <- bnames1
biome_cpt2 <- biome_cpt1
bnames3 <- bnames1
biome_cpt3 <- biome_cpt1

lab1 <- "Biomes_2010s"
lab2 <- "Biomes_2050s"
lab3 <- "Biomes_2090s"


# functions for 2-node and 3-node riverplots

#--------------------- Sankey diagram for 2 columns---------------------

plotSingleSankey <- function( BT1, BT2, lab1, lab2, bnames1, bnames2, biome_cpt1, biome_cpt2, title)
{
  	lengths_BTs <- array(0,c(2,nbiome))
	bcpt1 <- NULL
	bcpt2 <- NULL
	blab1 <- NULL
	blab2 <- NULL

	for(b in 1:nbiome)
	{
	 	lengths_BTs[1,b] <- length(which(BT1==b))
	 	lengths_BTs[2,b] <- length(which(BT2==b))
	 	
	 	if(lengths_BTs[1,b] > 0.)
	 	{
	 		bcpt1 <- c(bcpt1,biome_cpt1[b])
	 		blab1 <- c(blab1,bnames1[b])
		}
		if(lengths_BTs[2,b] > 0.)
		{
	 		bcpt2 <- c(bcpt2,biome_cpt2[b])
	 		blab2 <- c(blab2,bnames2[b])		
		}
	}	

  tt <- table(BT1,BT2)
  labs1 <- LETTERS[sort(unique(BT1))+1]
  labs2 <- letters[sort(unique(BT2))+1]
  
  nodes <- c(labs1, labs2)
   
  edges <- list()
  style <- list()
  
  for ( i in 1:length(labs1) )
  {
    l <- as.list( tt[i,] )
    
    names(l) <- labs2
    edges[[ i ]] <- l
    names(edges)[[i]] <- labs1[i]
    
    l <- list( col=bcpt1[i] )
    style[[ i ]] <- l
    names(style)[[i]] <- labs1[i]
  }
  
  i_start <- length(style)
  for ( i in 1:length(labs2) )
  {
    #   		l <- list( col=rgb(0.5, 0.5, 0, c_t) )
    l <- list( col=bcpt2[i] )
    style[[i_start+i]] <- l
    names(style)[[i_start+i]] <- labs2[i]
  }
  
  r <- makeRiver( nodes, edges, node_xpos= c( rep(1,length(labs1)), rep(2,length(labs2)) ),
                  node_labels= c( blab1, blab2 ),
                  node_styles= style )
  
  plot( r, nodewidth=6., plot_area=0.9, xscale=1, srt=0)
  mtext(lab1, 1, at=0.1, line=-0.05, cex=0.85)
  mtext(lab2, 1, at=0.9, line=-0.05, cex=0.85)
  mtext(title, 3, at=0.5, line=-0.05, cex=1.2)
}

#--------------------- Sankey diagram for 3 columns---------------------

plotSingleSankey3 <- function(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,title)
{

  const1 <- c("A1","B1","C1","D1","E1","F1","G1","H1","I1","J1")
  const2 <- c("A2","B2","C2","D2","E2","F2","G2","H2","I2","J2")
  const3 <- c("A3","B3","C3","D3","E3","F3","G3","H3","I3","J3")

  # find out which biomes exist (length > 0) to adjust the biome names vector and biome color vector to the existing biomes
  
  lengths_BTs <- array(0,c(3,nbiome))
  bcpt1 <- NULL
  blab1 <- NULL	

  for(b in 1:nbiome)
  {
 	lengths_BTs[1,b] <- length(which(BT1==b))
 	lengths_BTs[2,b] <- length(which(BT2==b))
 	lengths_BTs[3,b] <- length(which(BT3==b))
 	
 	if(all(lengths_BTs[,b] > 0.))
 	{
 		bcpt1 <- c(bcpt1,biome_cpt1[b])
 		blab1 <- c(blab1,bnames1[b])
 	}
  }
  
  bcpt2 <- bcpt1
  bcpt3 <- bcpt1
  
  blab2 <- blab1
  blab3 <- blab1
  
  labs1 <- const1[sort(unique(BT1))+1]
  labs2 <- const2[sort(unique(BT2))+1]
  labs3 <- const3[sort(unique(BT3))+1]

  tt <- table(BT1,BT2)
  
  edges1 <- list()
  style1 <- list()
  
  for ( i in 1:length(labs1) )
  {
    l <- as.list( tt[i,] )
    
    names(l) <- labs2
    edges1[[ i ]] <- l
    names(edges1)[[i]] <- labs1[i]
    
    l <- list( col=bcpt1[i] )
    style1[[ i ]] <- l
    names(style1)[[i]] <- labs1[i]
  }
  
  i_start <- length(style1)
  for ( i in 1:length(labs2) )
  {
    #   		l <- list( col=rgb(0.5, 0.5, 0, c_t) )
    l <- list( col=bcpt2[i] )
    style1[[i_start+i]] <- l
    names(style1)[[i_start+i]] <- labs2[i]
  }
  
  tt1 <- table(BT2,BT3)
  
  edges2 <- list()
  style2 <- list()
  
  for ( i in 1:length(labs2) )
  {
    l <- as.list( tt1[i,] )
    
    names(l) <- labs3
    edges2[[ i ]] <- l
    names(edges2)[[i]] <- labs2[i]
    
    l <- list( col=bcpt2[i] )
    style2[[ i ]] <- l
    names(style2)[[i]] <- labs2[i]
  }
  
  i_start <- length(style2)
  for ( i in 1:length(labs3) )
  {
    #   		l <- list( col=rgb(0.5, 0.5, 0, c_t) )
    l <- list( col=bcpt3[i] )
    style2[[i_start+i]] <- l
    names(style2)[[i_start+i]] <- labs3[i]
  }
  
  edges <- append(edges1,edges2)
  styles <- append(style1,style2)
  
  nodes  <- c(labs1, labs2,labs3)
  
  r <- makeRiver(nodes = nodes, edges = edges,
                 node_xpos= c( rep(1,length(labs1)), rep(2,length(labs2)),rep(3,length(labs3)) ),
                 node_labels= c( blab1,blab2,blab3),
                 node_styles= styles)
  op <- par(cex=0.85)
  plot( r, nodewidth=6, plot_area=0.9, xscale=1, srt=0)
  op <- par(cex=0.85)
  mtext(lab1, 1, at=0.05, line=-0.05, cex=0.85)
  mtext(lab2, 1, at=0.5, line=-0.05, cex=0.85)
  mtext(lab3, 1, at=0.95, line=-0.05, cex=0.85) #ffcf0f
  mtext(title, 3, at=0.5, line=-0.05, cex=1.2)
}

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure B1. Sankey diagrams showing the change of biomes between the three decades of interest, for both RCP scenarios with fire. ”T_“
# denotes transient scenarios, ”E_“ denotes equilibrium scenarios.

message("Creating Figure B1")

graphics.off()
pdf("Figure_B1.pdf",width=11,height=11)
par(mfrow=c(2,2),oma=c(1,1,1,1),mar=c(2,1,2,1))

# temporal development transient RCP8.5wifi

d1_in <- as.integer(c(BT[,,twf85,5]))
d2_in <- as.integer(c(BT[,,twf85,9]))
d3_in <- as.integer(c(BT[,,twf85,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")
d3 <- which(d3_in != "NA")

ind_all <- intersect(d1, d2)
ind_all <- intersect(ind_all,d3)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]
BT3 <- d3_in[ind_all]

plotSingleSankey3(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,"T_RCP8.5_wifi")

# temporal development equilibrium RCP8.5wifi

d1_in <- as.integer(c(BT[,,ewf85,5]))
d2_in <- as.integer(c(BT[,,ewf85,9]))
d3_in <- as.integer(c(BT[,,ewf85,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")
d3 <- which(d3_in != "NA")

ind_all <- intersect(d1, d2)
ind_all <- intersect(ind_all,d3)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]
BT3 <- d3_in[ind_all]

plotSingleSankey3(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,"E_RCP8.5_wifi")		

# temporal development transient RCP4.5wifi

d1_in <- as.integer(c(BT[,,twf45,5]))
d2_in <- as.integer(c(BT[,,twf45,9]))
d3_in <- as.integer(c(BT[,,twf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")
d3 <- which(d3_in != "NA")

ind_all <- intersect(d1, d2)
ind_all <- intersect(ind_all,d3)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]
BT3 <- d3_in[ind_all]

plotSingleSankey3(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,"T_RCP4.5_wifi")

# temporal development equilibrium RCP4.5wifi

d1_in <- as.integer(c(BT[,,ewf45,5]))
d2_in <- as.integer(c(BT[,,ewf45,9]))
d3_in <- as.integer(c(BT[,,ewf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")
d3 <- which(d3_in != "NA")

ind_all <- intersect(d1, d2)
ind_all <- intersect(ind_all,d3)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]
BT3 <- d3_in[ind_all]

plotSingleSankey3(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,"E_RCP4.5_wifi")

graphics.off()	

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure B2. Sankey diagrams showing the change of biomes between the three decades of interest, for both RCP scenarios without fire. ”T_“
# denotes transient scenarios, ”E_“ denotes equilibrium scenarios.

message("Creating Figure B2")

graphics.off()
pdf("Figure_B2.pdf",width=11,height=11)
par(mfrow=c(2,2),oma=c(1,1,1,1),mar=c(2,1,2,1))

# temporal development transient RCP8.5nofi 

d1_in <- as.integer(c(BT[,,tnf85,5]))
d2_in <- as.integer(c(BT[,,tnf85,9]))
d3_in <- as.integer(c(BT[,,tnf85,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")
d3 <- which(d3_in != "NA")

ind_all <- intersect(d1, d2)
ind_all <- intersect(ind_all,d3)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]
BT3 <- d3_in[ind_all]

plotSingleSankey3(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,"T_RCP8.5_nofi")	

# temporal development equilibrium RCP8.5nofi 
# BT 4 and 5 are missing

d1_in <- as.integer(c(BT[,,enf85,5]))
d2_in <- as.integer(c(BT[,,enf85,9]))
d3_in <- as.integer(c(BT[,,enf85,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")
d3 <- which(d3_in != "NA")

ind_all <- intersect(d1, d2)
ind_all <- intersect(ind_all,d3)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]
BT3 <- d3_in[ind_all]

plotSingleSankey3(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,"E_RCP8.5_nofi")

# temporal development transient RCP4.5nofi 

d1_in <- as.integer(c(BT[,,tnf45,5]))
d2_in <- as.integer(c(BT[,,tnf45,9]))
d3_in <- as.integer(c(BT[,,tnf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")
d3 <- which(d3_in != "NA")

ind_all <- intersect(d1, d2)
ind_all <- intersect(ind_all,d3)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]
BT3 <- d3_in[ind_all]

plotSingleSankey3(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,"T_RCP4.5_nofi")

# temporal development equilibrium RCP4.5nofi 

d1_in <- as.integer(c(BT[,,enf45,5]))
d2_in <- as.integer(c(BT[,,enf45,9]))
d3_in <- as.integer(c(BT[,,enf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")
d3 <- which(d3_in != "NA")

ind_all <- intersect(d1, d2)
ind_all <- intersect(ind_all,d3)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]
BT3 <- d3_in[ind_all]

plotSingleSankey3(BT1,BT2,BT3,lab1,lab2,lab3,bnames1,bnames2,bnames3,biome_cpt1,biome_cpt2,biome_cpt3,"E_RCP4.5_nofi")

graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure B3. Sankey diagrams showing the difference in biome type between scenarios with fire and scenarios without fire for RCP8.5, for the
# three decades of interest (2010s, 2050s, 2090s). ”T_“ denotes transient scenarios, ”E_“ denotes equilibrium scenarios.

message("Creating Figure B3")

graphics.off()
pdf("Figure_B3.pdf",width=11,height=17)
par(mfrow=c(3,2),oma=c(1,1,1,1),mar=c(2,1,2,1))

d1_in <- as.integer(c(BT[,,twf85,5]))
d2_in <- as.integer(c(BT[,,tnf85,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

scen1 <- "RCP8.5_wifi"
scen2 <- "RCP8.5_nofi"
plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5_wifinofi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,ewf85,5]))
d2_in <- as.integer(c(BT[,,enf85,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5_wifinofi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,twf85,9]))
d2_in <- as.integer(c(BT[,,tnf85,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5_wifinofi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,ewf85,9]))
d2_in <- as.integer(c(BT[,,enf85,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5_wifinofi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,twf85,13]))
d2_in <- as.integer(c(BT[,,tnf85,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5_wifinofi_2090s")

#--------------------------------------

d1_in <- as.integer(c(BT[,,ewf85,13]))
d2_in <- as.integer(c(BT[,,enf85,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5_wifinofi_2090s")

graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure B4. Sankey diagrams showing the difference in biome type between scenarios with fire and scenarios without fire for RCP4.5, for the
# three decades of interest (2010s, 2050s, 2090s). ”T_“ denotes transient scenarios, ”E_“ denotes equilibrium scenarios.

message("Creating Figure B4")

graphics.off()
pdf("Figure_B4.pdf",width=11,height=17)
par(mfrow=c(3,2),oma=c(1,1,1,1),mar=c(2,1,2,1))

d1_in <- as.integer(c(BT[,,twf45,5]))
d2_in <- as.integer(c(BT[,,tnf45,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

scen1 <- "RCP4.5_wifi"
scen2 <- "RCP4.5_nofi"
plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_4.5_wifinofi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,ewf45,5]))
d2_in <- as.integer(c(BT[,,enf45,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_4.5_wifinofi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,twf45,9]))
d2_in <- as.integer(c(BT[,,tnf45,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_4.5_wifinofi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,ewf45,9]))
d2_in <- as.integer(c(BT[,,enf45,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_4.5_wifinofi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,twf45,13]))
d2_in <- as.integer(c(BT[,,tnf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_4.5_wifinofi_2090s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,ewf45,13]))
d2_in <- as.integer(c(BT[,,enf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_4.5_wifinofi_2090s")

graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure B5. Sankey diagrams showing the difference in biome type between transient and equilibrium scenarios for RCP8.5, for the three
# decades of interest (2010s, 2050s, 2090s). ”wifi“ denotes scenarios with fire, ”nofi“ denotes scenarios without fire.

message("Creating Figure B5")

graphics.off()
pdf("Figure_B5.pdf",width=11,height=17)
par(mfrow=c(3,2),oma=c(1,1,1,1),mar=c(2,1,2,1))

d1_in <- as.integer(c(BT[,,twf85,5]))
d2_in <- as.integer(c(BT[,,ewf85,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

scen1 <- "transient"
scen2 <- "equilibrium"
plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "8.5wifi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,tnf85,5]))
d2_in <- as.integer(c(BT[,,enf85,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "8.5nofi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,twf85,9]))
d2_in <- as.integer(c(BT[,,ewf85,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "8.5wifi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,tnf85,9]))
d2_in <- as.integer(c(BT[,,enf85,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "8.5nofi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,twf85,13]))
d2_in <- as.integer(c(BT[,,ewf85,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "8.5wifi_2090s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,tnf85,13]))
d2_in <- as.integer(c(BT[,,enf85,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5-4.5_nofi_2090s")

graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure B6. Sankey diagrams showing the difference in biome type between transient and equilibrium scenarios for RCP4.5, for the three
# decades of interest (2010s, 2050s, 2090s). ”wifi“ denotes scenarios with fire, ”nofi“ denotes scenarios without fire.

message("Creating Figure B6")

graphics.off()
pdf("Figure_B6.pdf",width=11,height=17)
par(mfrow=c(3,2),oma=c(1,1,1,1),mar=c(2,1,2,1))

d1_in <- as.integer(c(BT[,,twf45,5]))
d2_in <- as.integer(c(BT[,,ewf45,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

scen1 <- "transient"
scen2 <- "equilibrium"
plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "4.5wifi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,tnf45,5]))
d2_in <- as.integer(c(BT[,,enf45,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "4.5nofi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,twf45,9]))
d2_in <- as.integer(c(BT[,,ewf45,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "4.5wifi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,tnf45,9]))
d2_in <- as.integer(c(BT[,,enf45,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "4.5nofi_2050s")

#---------------------------------------	

d1_in <- as.integer(c(BT[,,twf45,13]))
d2_in <- as.integer(c(BT[,,ewf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "4.5wifi_2090s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,tnf45,13]))
d2_in <- as.integer(c(BT[,,enf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_4.5-4.5_nofi_2090s")

graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure B7. Sankey diagrams showing the difference in biome type between RCP8.5 and RCP4.5 with fire, for the three decades of interest
# (2010s, 2050s, 2090s). ”T_“ denotes transient scenarios, ”E_“ denotes equilibrium scenarios.

message("Creating Figure B7")

graphics.off()
pdf("Figure_B7.pdf",width=11,height=17)
par(mfrow=c(3,2),oma=c(1,1,1,1),mar=c(2,1,2,1))

d1_in <- as.integer(c(BT[,,twf85,5]))
d2_in <- as.integer(c(BT[,,twf45,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

scen1 <- "RCP8.5_wifi"
scen2 <- "RCP4.5_wifi"
plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5-4.5_wifi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,ewf85,5]))
d2_in <- as.integer(c(BT[,,ewf45,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5-4.5_wifi_2010s")

#---------------------------------------


d1_in <- as.integer(c(BT[,,twf85,9]))
d2_in <- as.integer(c(BT[,,twf45,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5-4.5_wifi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,ewf85,9]))
d2_in <- as.integer(c(BT[,,ewf45,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5-4.5_wifi_2050s")

#---------------------------------------


d1_in <- as.integer(c(BT[,,twf85,13]))
d2_in <- as.integer(c(BT[,,twf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5-4.5_wifi_2090s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,ewf85,13]))
d2_in <- as.integer(c(BT[,,ewf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5-4.5_wifi_2090s")

graphics.off()

#-------------------------------------------------------------------------------------------------------------------------------------
# Figure B8. Sankey diagrams showing the difference in biome type between RCP8.5 and RCP4.5 without fire, for the three decades of interest
# (2010s, 2050s, 2090s). ”T_“ denotes transient scenarios, ”E_“ denotes equilibrium scenarios.

message("Creating Figure B8")

graphics.off()
pdf("Figure_B8.pdf",width=11,height=17)
par(mfrow=c(3,2),oma=c(1,1,1,1),mar=c(2,1,2,1))

d1_in <- as.integer(c(BT[,,tnf85,5]))
d2_in <- as.integer(c(BT[,,tnf45,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

scen1 <- "RCP8.5_nofi"
scen2 <- "RCP4.5_nofi"
plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5-4.5_nofi_2010s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,enf85,5]))
d2_in <- as.integer(c(BT[,,enf45,5]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5-4.5_nofi_2010s")

#---------------------------------------


d1_in <- as.integer(c(BT[,,tnf85,9]))
d2_in <- as.integer(c(BT[,,tnf45,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5-4.5_nofi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,enf85,9]))
d2_in <- as.integer(c(BT[,,enf45,9]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5-4.5_nofi_2050s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,tnf85,13]))
d2_in <- as.integer(c(BT[,,tnf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "T_8.5-4.5_nofi_2090s")

#---------------------------------------

d1_in <- as.integer(c(BT[,,enf85,13]))
d2_in <- as.integer(c(BT[,,enf45,13]))

d1 <- which(d1_in != "NA")
d2 <- which(d2_in != "NA")

ind_all <- intersect(d1, d2)

BT1 <- d1_in[ind_all]
BT2 <- d2_in[ind_all]

plotSingleSankey( BT1, BT2, scen1, scen2, bnames1, bnames2, biome_cpt1, biome_cpt2, "E_8.5-4.5_nofi_2090s")

graphics.off()


